@@ -1,4 +1,4 @@
-#    $Id: Nominet.pm,v 1.21 2019/03/18 14:58:27 pete Exp $
+#    $Id: Nominet.pm,v 1.22 2019/06/21 14:31:33 pete Exp $
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -29,12 +29,16 @@ use constant EPP_XMLNS	=> 'urn:ietf:params:xml:ns:epp-1.0';
 use vars qw($Error $Code $Message);
 
 BEGIN {
-	our $VERSION = '0.03_02';
+	our $VERSION = '0.03_03';
 }
 
 # file-scoped lexicals
-my $Host      = 'epp.nominet.org.uk';
-my $Hosttest  = 'testbed-epp.nominet.org.uk';
+my %Host      = (
+	prod => 'epp.nominet.org.uk',
+	test => 'testbed-epp.nominet.org.uk',
+	ror  => 'ror-epp.nominet.org.uk',
+	ote  => 'ote-epp.nominet.org.uk',
+);
 my $EPPVer    = '1.0';
 my $EPPLang   = 'en';
 my $NSVer     = '2.0';
@@ -110,9 +114,13 @@ exceptions:
 
 =over
 
-=item * If C<test> is set but C<testssl> is not, C<port> defaults to 8700
+=item * If C<test> or C<ote> is set but C<testssl> is not, C<port>
+defaults to 8700
 
-=item * if C<test> is set, C<host> defaults to 'testbed-epp.nominet.org.uk'. Otherwise C<host> defaults to 'epp.nominet.org.uk'.
+=item * C<host> will be set to the appropriate endpoint. Specify C<ote>
+with value 1 to connect to the OT&E endpoint, C<ror> with value 1 for
+the RoR endpoint, C<test> with value 1 for the testbed endpoint and none
+of these for the standard live endpoint.
 
 =item * C<timeout> defaults to 5 (seconds).
 
@@ -158,13 +166,28 @@ sub new {
 			$params{port} = 8700;
 			$params{ssl}  = undef;
 		}
-		$params{host} = $Hosttest;
+		$params{host} = $Host{test};
+	} elsif ($params{ote} and $params{ote} == 1) {
+		# Use OT&E server
+		if ($params{testssl} and $params{testssl} == 1) {
+			$params{port} = 700;
+			$params{ssl}  =   1;
+		} else {
+			$params{port} = 8700;
+			$params{ssl}  = undef;
+		}
+		$params{host} = $Host{ote};
 	} else {
 		# Use live server
 		$params{port} = 700;
 		$params{ssl}  =   1;
-		$params{host} = $Host;
+		if ($params{ror} and $params{ror} == 1) {
+			$params{host} = $Host{ror};
+		} else {
+			$params{host} = $Host{prod};
+		}
 	}
+	warn "Connecting to $params{host}:$params{port}\n" if $Debug;
 	$params{timeout}	= (int($params{timeout} || 0) > 0 ? $params{timeout} : 5);
 	if ($params{ssl}) {
 		if ($params{verify}) {
@@ -363,9 +386,11 @@ sub _check {
 	$count = $extra->getAttribute('abuse-limit') if defined $extra;
 	warn "Remaining checks = $count\n" if ($Debug and defined $count);
 
+	# Rights disappear after 24/06/2019
 	my $rights = undef;
 	if ($type eq 'domain' and $identifier !~ /\..*\./) {
-		$extra  = $response->getNode("nom-direct-rights:ror")->firstChild;
+		$extra  = $response->getNode("nom-direct-rights:ror") and
+			$extra  = $extra->firstChild;
 		$rights = $extra->toString if defined $extra;
 	}
 
